import { EsbuildTransformOptions, Plugin } from "vite";
import type { Config as SvgrConfig } from "@svgr/core";
import type { Config as SvgoConfig } from "svgo";
export interface PluginOptions {
    /**
     * If "include" predicate is present, only passing paths will be processed
     * @param path E.g "C:/path/to/my-svg.svg"
     * @returns Whether given path should be processed by the plugin or not
     */
    include?: (path: string) => boolean;
    /**
     * If "exclude" predicate is present, every path excluding passing paths will be processed
     * @param path E.g "C:/path/to/my-svg.svg"
     * @returns Whether given path should be discarded or processed by the plugin
     */
    exclude?: (path: string) => boolean;
    /**
     * Options used while resolving as "?raw"
     */
    rawLoaderOptions?: {
        /**
         * Enables SVGO optimizations while loading the SVG asset
         * @default false
         */
        svgoEnabled?: boolean;
        /**
         * Options used while running SVGO optimizations on the original SVG asset
         */
        svgoConfig?: SvgoConfig;
    };
    /**
     * Options used while resolving as "?url"
     */
    urlLoaderOptions?: {
        /**
         * Enables SVGO optimizations while loading the SVG asset
         * @default false
         */
        svgoEnabled?: boolean;
        /**
         * Options used while running SVGO optimizations on the original SVG asset
         */
        svgoConfig?: SvgoConfig;
    };
    /**
     * Options used while resolving as "?base64"
     */
    base64LoaderOptions?: {
        /**
         * Enables SVGO optimizations while loading the SVG asset
         * @default false
         */
        svgoEnabled?: boolean;
        /**
         * Options used while running SVGO optimizations on the original SVG asset
         */
        svgoConfig?: SvgoConfig;
    };
    /**
     * Options used while resolving as "?component"
     */
    componentLoaderOptions?: {
        /**
         * Options used while running SVGR transform on the original svg asset
         */
        svgrConfig?: SvgrConfig;
        /**
         * Options used to generate JSX Component code with given SVGR output
         */
        esbuildConfig?: EsbuildTransformOptions;
    };
}
export default function (options?: PluginOptions): Plugin;
